@@ -1,7 +1,7 @@
 package App::ZodiacUtils;
 
 our $DATE = '2015-11-28'; # DATE
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.04'; # VERSION
 
 use 5.010001;
 use strict;
@@ -13,21 +13,21 @@ $SPEC{zodiac_of} = {
     v => 1.1,
     summary => 'Show zodiac for a date',
     args => {
-        # dates => {
-        date => {
-            summary => 'Date',
+        dates => {
+            summary => 'Dates',
+            'x.name.is_plural' => 1,
             #schema => ['array*', of=>'date*', min_len=>1],
-            schema => 'date*',
-            'x.perl.coerce_to' => 'DateTime',
+            schema => ['array*', of=>'str*', min_len=>1],
+            #'x.perl.coerce_to' => 'int(epoch)',
             req => 1,
             pos => 0,
-            #greedy => 1,
+            greedy => 1,
         },
     },
     result_naked => 1,
     examples => [
         {
-            args => {date=>'2015-06-15'},
+            args => {dates=>['2015-06-15']},
             result => 'gemini',
             test => 0, # at the time of this writing, Test::Rinci hasn't used Perinci::Sub::CoerceArgs
         },
@@ -37,12 +37,16 @@ sub zodiac_of {
     require Zodiac::Tiny;
     my %args = @_;
 
-    #my $dates = $args{dates};
-    my $dates = [$args{date}];
+    my $dates = $args{dates};
 
     my $res = [];
     for my $date (@$dates) {
-        push @$res, Zodiac::Tiny::zodiac_of($date);
+        unless ($date =~ /\A\d\d\d\d-\d\d-\d\d\z/) {
+            warn "Invalid date '$date'\n";
+            next;
+        }
+        my $z = Zodiac::Tiny::zodiac_of($date);
+        push @$res, @$dates > 1 ? [$date, $z] : $z;
     }
     $res = $res->[0] if @$res == 1;
     $res;
@@ -52,21 +56,21 @@ $SPEC{chinese_zodiac_of} = {
     v => 1.1,
     summary => 'Show Chinese zodiac for a date',
     args => {
-        # dates => {
-        date => {
-            summary => 'Date',
+        dates => {
+            summary => 'Dates',
+            'x.name.is_plural' => 1,
             #schema => ['array*', of=>'date*', min_len=>1],
-            schema => 'date*',
-            'x.perl.coerce_to' => 'DateTime',
+            schema => ['array*', of=>'str*', min_len=>1],
+            #'x.perl.coerce_to' => 'int(epoch)',
             req => 1,
             pos => 0,
-            #greedy => 1,
+            greedy => 1,
         },
     },
     result_naked => 1,
     examples => [
         {
-            args => {date=>'1980-02-17'},
+            args => {dates=>['1980-02-17']},
             result => 'monkey (metal)',
         },
     ],
@@ -76,14 +80,17 @@ sub chinese_zodiac_of {
     require Zodiac::Chinese::Table;
     my %args = @_;
 
-    #my $dates = $args{dates};
-    my $dates = [$args{date}];
+    my $dates = $args{dates};
 
     my $res = [];
     for my $date (@$dates) {
-        my $czres = Zodiac::Chinese::Table::chinese_zodiac(
-            ref($date) ? $date->ymd : $date);
-        push @$res, $czres ? "$czres->[7] ($czres->[3])" : undef;
+        unless ($date =~ /\A\d\d\d\d-\d\d-\d\d\z/) {
+            warn "Invalid date '$date'\n";
+            next;
+        }
+        my $czres = Zodiac::Chinese::Table::chinese_zodiac($date);
+        my $z = $czres ? "$czres->[7] ($czres->[3])" : undef;
+        push @$res, @$dates > 1 ? [$date, $z] : $z;
     }
     $res = $res->[0] if @$res == 1;
     $res;
@@ -104,7 +111,7 @@ App::ZodiacUtils - CLI utilities related to zodiac
 
 =head1 VERSION
 
-This document describes version 0.03 of App::ZodiacUtils (from Perl distribution App-ZodiacUtils), released on 2015-11-28.
+This document describes version 0.04 of App::ZodiacUtils (from Perl distribution App-ZodiacUtils), released on 2015-11-28.
 
 =head1 DESCRIPTION
 
@@ -127,16 +134,16 @@ Show Chinese zodiac for a date.
 
 Examples:
 
- chinese_zodiac_of( date => "1980-02-17"); # -> "monkey (metal)"
+ chinese_zodiac_of( dates => ["1980-02-17"]); # -> "monkey (metal)"
 This function is not exportable.
 
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<date>* => I<date>
+=item * B<dates>* => I<array[str]>
 
-Date.
+Dates.
 
 =back
 
@@ -158,16 +165,16 @@ Show zodiac for a date.
 
 Examples:
 
- zodiac_of( date => "2015-06-15"); # -> "gemini"
+ zodiac_of( dates => ["2015-06-15"]); # -> "gemini"
 This function is not exportable.
 
 Arguments ('*' denotes required arguments):
 
 =over 4
 
-=item * B<date>* => I<date>
+=item * B<dates>* => I<array[str]>
 
-Date.
+Dates.
 
 =back
 
